#undef PACKAGE
#undef VERSION

/* Define if you have a long long type */
#undef HAVE_LONG_LONG

/* Define if you have a working dlopen() */
#undef HAVE_DLOPEN

/* Define to include support for multi-threading */
#undef O_PLMT

/* Define to make use of standard (UNIX98) pthread recursive mutexes */
#undef RECURSIVE_MUTEXES

/* Define to the extension of shared objects (.so normally) */
#undef SO_EXT

/* Define this will enable shared objects loading interface (plugins)*/
#undef USE_SHARED_LOADING

/* Define if you have _GNU_SOURCE getpt() */
#undef HAVE_GETPT

/* Define possible pty types */
#undef PTYS_ARE_OPENPTY
#undef PTYS_ARE_NUMERIC
#undef PTYS_ARE_PTMX
#undef PTYS_ARE_PTC
#undef PTYS_ARE__GETPTY
#undef PTYS_ARE_GETPTY
#undef PTYS_ARE_GETPT
#undef PTYS_ARE_CLONE
#undef PTYS_ARE_SEARCHED

/* ------------ End of file -------------- */

